.. :changelog:

History
-------
0.0.5 (2019-11-11)
++++++++++++++++++
* dovpanda errors don't crash panda

 * Errors in functionality of dovpanda will only tell the user it happened
   but let them continue the work

* fix read_csv issue #76
* fix at/iat issues when calling shape on str #77

0.0.4 (2019-11-09)
++++++++++++++++++
* fix to import error issue #71

0.0.3 (2019-11-08)
++++++++++++++++++
* First published release

0.0.2 (2019-10-30)
++++++++++++++++++

* First release on PyPI.
